==> xsw-1.34.0.tar.bz2: xsw-1.34.0/unvedit/uewprops.h <==
/*
            Universe Editor Window: Properties Pane

 */




#ifndef UEWPROPS_H
#define UEWPROPS_H


/* Height of each property prompt in pixels. */
#define UEW_PROP_PROMPT_HEIGHT	30


/*
 *	Property parameter names.
 */
#define PROP_NAME	{				\
	"Name",				/* 0 */ 	\
	"Password",					\
	"Empire",					\
	"ELink",					\
	"LastUpdated",					\
	"Type",						\
	"LocType",					\
	"ImageSet",					\
	"Owner",					\
	"Size",						\
	"LockedOn",			/* 10 */	\
	"InterceptingObject",				\
	"ScannerRange",					\
	"SectX",					\
	"SectY",					\
	"SectZ",					\
	"X",						\
	"Y",						\
	"Z",						\
	"Heading",					\
	"Pitch",			/* 20 */	\
	"Bank",						\
	"Velocity",					\
	"VelocityMax",					\
	"VelocityHeading",				\
	"VelocityPitch",				\
	"VelocityBank",					\
	"ThrustDir",					\
	"Thrust",					\
	"ThrustPower",					\
	"Throttle",			/* 30 */	\
	"EngineState",					\
	"TurnRate",					\
	"Lighting",					\
	"Hp",						\
	"HpMax",					\
	"Power",					\
	"PowerMax",					\
	"PowerPurity",					\
	"CoreEfficency",				\
	"Antimatter",			/* 40 */	\
	"AntimatterMax",				\
	"ShieldState",					\
	"ShieldFrequency",				\
	"SelectedWeapon",				\
	"TotalWeapons",					\
	"BirthTime",					\
	"LifeSpan",					\
	"CloakState",					\
	"CloakStrength",				\
	"Visibility",			/* 50 */	\
	"CurVisibility",				\
	"ShieldVisibility",				\
	"DamageControl",				\
	"ComChannel",					\
	"AIFlags",					\
/* Skip tractored objects. */				\
	"PermissionUID",				\
	"PermissionGID",				\
	"AnimationInterval",				\
	"AnimationLastInterval",			\
	"AnimationCurrentFrame",	/* 60 */	\
	"AnimationTotalFrames",				\
	"AnimationCycleCount",				\
	"AnimationCycleTimes",				\
	"ScoreCredits",					\
	"ScoreRMU",					\
	"ScoreRMUMax",					\
	"ScoreDamageGiven",				\
	"ScoreDamageRecieved",				\
	"ScoreKills"			/* 69 */	\
}


/* Total number of property prompts, this should match the number of
 * strings in PROP_NAME.
 */
#define TOTAL_PROP_PROMPTS		70


#endif	/* UEWPROPS_H */

==> xsw-2.5.5.tar.bz2: xsw-2.5.5/unvedit/uewprops.h <==
#ifndef UEWPROPS_H
#define UEWPROPS_H


#define UEW_PROP_PROMPT_HEIGHT		30

/*
 *	Object Property Names List:
 */
#define UE_OBJECT_PROPERTY_NAMES_LIST	{		\
	"Name",				/* 0 */ 	\
	"Password",					\
	"Empire",					\
	"Description",					\
	"ELink",					\
	"LastUpdated",					\
	"Type",						\
	"LocType",					\
	"ImgRef",					\
	"Owner",					\
	"Size",				/* 10 */	\
	"LockedOn",					\
	"InterceptingObject",				\
	"ScannerRange",					\
	"SectX",					\
	"SectY",					\
	"SectZ",					\
	"X",						\
	"Y",						\
	"Z",						\
	"Heading",			/* 20 */	\
	"Pitch",					\
	"Bank",						\
	"Velocity",					\
	"VelocityMax",					\
	"VelocityHeading",				\
	"VelocityPitch",				\
	"VelocityBank",					\
	"ThrustDir",					\
	"Thrust",					\
	"ThrustPower",			/* 30 */	\
	"Throttle",					\
	"EngineState",					\
	"TurnRate",					\
	"Lighting",					\
	"Hp",						\
	"HpMax",					\
	"Power",					\
	"PowerMax",					\
	"PowerPurity",					\
	"CoreEfficency",		/* 40 */	\
	"Antimatter",					\
	"AntimatterMax",				\
	"ShieldState",					\
	"ShieldFrequency",				\
	"SelectedWeapon",				\
	"TotalWeapons",					\
	"BirthTime",					\
	"LifeSpan",					\
	"CloakState",					\
	"CloakStrength",		/* 50 */	\
	"Visibility",					\
	"CurVisibility",				\
	"ShieldVisibility",				\
	"DamageControl",				\
	"ComChannel",					\
	"AIFlags",					\
/* Skip tractored objects */				\
	"PermissionUID",				\
	"PermissionGID",				\
	"AnimationInterval",				\
	"AnimationLastInterval",	/* 60 */	\
	"AnimationCurrentFrame",			\
	"AnimationTotalFrames",				\
	"AnimationCycleCount",				\
	"AnimationCycleTimes",				\
	"ScoreCredits",					\
	"ScoreRMU",					\
	"ScoreRMUMax",					\
	"ScoreDamageGiven",				\
	"ScoreDamageRecieved",				\
	"ScoreKills"			/* 70 */	\
}


/* Total number of property prompts, this should match the number of
 * strings in PROP_NAME.
 */
#define UEW_TOTAL_PROPS			71


#endif	/* UEWPROPS_H */
